==> rdd_2.0.7.orig.tar.gz: rdd-2.0.7/src/netio.h <==
/*
 * Copyright (c) 2002 - 2006, Netherlands Forensic Institute
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */



#ifndef __netio_h__
#define __netio_h__

#include "msgprinter.h"

typedef enum _rdd_net_flags_t {
	RDD_NET_COMPRESS = 0x1
} rdd_net_flags_t;

int rdd_init_server(RDD_MSGPRINTER *printer, unsigned port,
			int *server_sock);

int rdd_await_connection(RDD_MSGPRINTER *printer, int server_sock,
			int *client_sock);

int rdd_recv_info(RDD_READER *reader, char **filename,
	rdd_count_t *file_size, rdd_count_t *block_size, rdd_count_t *split_size,
	unsigned *flags);

int rdd_send_info(RDD_WRITER *writer, char *file_name,
		rdd_count_t file_size,
		rdd_count_t block_size,
		rdd_count_t split_size,
		unsigned flags);

#endif /* __netio_h__ */

==> rdd-3.0.4.tar.gz: rdd-3.0.4/src/netio.h <==
/*
 * Copyright (c) 2002 - 2006, Netherlands Forensic Institute
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */



#ifndef __netio_h__
#define __netio_h__

#include "msgprinter.h"
#include "reader.h"

typedef enum _rdd_net_flags_t {
	RDD_NET_COMPRESS = 0x1
} rdd_net_flags_t;

int rdd_init_server(RDD_MSGPRINTER *printer, unsigned int port,
			int *server_sock);

int rdd_await_connection(RDD_MSGPRINTER *printer, int server_sock,
			int *client_sock);

int rdd_recv_info(RDD_READER *reader, char **filename,
	rdd_count_t *file_size, rdd_count_t *block_size, rdd_count_t *split_size,
	int *ewf, unsigned *flags);

int rdd_send_info(RDD_WRITER *writer, char *file_name,
		rdd_count_t file_size,
		rdd_count_t block_size,
		rdd_count_t split_size,
		int ewf,
		unsigned flags);

#endif /* __netio_h__ */
